@@ -9,13 +9,13 @@
 #include <unistd.h>
 #include <time.h>
 
-#include <qmessagebox.h>
 #include <qpopupmenu.h>
 
 #include <klocale.h>
 #include <ksimpleconfig.h>
 #include <kmessagebox.h>
 #include <kwin.h>
+#include <kwinmodule.h>
 #include <kapp.h>
 
 #include "amor.h"
@@ -23,7 +23,7 @@
 #include "amorpm.h"
 #include "amorbubble.h"
 #include "version.h"
-
+#include <kdebug.h>
 #include <X11/Xlib.h>
 
 #define SLEEP_TIMEOUT   180     // Animation sleeps after SLEEP_TIMEOUT seconds
@@ -64,6 +64,16 @@ Amor::Amor() : QObject()
         mCursId      = 0;
         mBubbleId    = 0;
 
+        mWin = new KWinModule;
+        connect(mWin, SIGNAL(activeWindowChanged(WId)),
+                this, SLOT(slotWindowActivate(WId)));
+        connect(mWin, SIGNAL(windowRemoved(WId)),
+                this, SLOT(slotWindowRemove(WId)));
+        connect(mWin, SIGNAL(stackingOrderChanged()),
+                this, SLOT(slotStackingChanged()));
+        connect(mWin, SIGNAL(windowChanged(WId)),
+                this, SLOT(slotWindowChange(WId)));
+
         mAmor = new AmorWidget();
         connect(mAmor, SIGNAL(mouseClicked(const QPoint &)),
                         SLOT(slotMouseClicked(const QPoint &)));
@@ -76,9 +86,9 @@ Amor::Amor() : QObject()
         mCursPos = QCursor::pos();
         mCursId = startTimer(200);
 
-        if (KWin::activeWindow())
+        if (mWin->activeWindow())
         {
-            mNextTarget = KWin::activeWindow();
+            mNextTarget = mWin->activeWindow();
             selectAnimation(Focus);
             mTimer->start(0, true);
         }
@@ -95,6 +105,7 @@ Amor::Amor() : QObject()
 //
 Amor::~Amor()
 {
+    delete mWin;
     delete mAmor;
     delete mBubble;
 }
@@ -134,6 +145,8 @@ bool Amor::readConfig()
     // Read user preferences
     mConfig.read();
 
+//    mConfig.mOnTop = true;       // XXX until normal mode is fixed
+
     if (mConfig.mTips)
     {
         mTips.setFile(TIPS_FILE);
@@ -171,7 +184,7 @@ bool Amor::readConfig()
 //
 void Amor::showBubble(const QString& msg)
 {
-    if (msg)
+    if (!msg.isNull())
     {
         if (!mBubble)
         {
@@ -225,8 +238,9 @@ void Amor::selectAnimation(State state)
             mTargetWin = mNextTarget;
             if (mTargetWin != None)
             {
-                mTargetRect = windowGeometry(mTargetWin);
+//                mTargetRect = windowGeometry(mTargetWin);
 //                mTargetRect = KWM::geometry(mTargetWin, true);
+                mTargetRect = KWin::info(mTargetWin).frameGeometry;
                 if (mCurrAnim->frame())
                 {
                     mPosition = (kapp->random() %
@@ -311,30 +325,32 @@ void Amor::restack()
         return;
     }
 
-    debug("restacking");
+    kdDebug(10000) << "restacking" << endl;
 
+    Window sibling = mTargetWin;
     Window dw, parent = None, *wins;
-    unsigned int nwins = 0;
 
-    // We must use the target window's parent as our sibling.
-    // Is there a faster way to get parent window than XQueryTree?
-    if (XQueryTree(qt_xdisplay(), mTargetWin, &dw, &parent, &wins, &nwins))
-    {
-        if (nwins)
+    do {
+        unsigned int nwins = 0;
+
+        // We must use the target window's parent as our sibling.
+        // Is there a faster way to get parent window than XQueryTree?
+        if (XQueryTree(qt_xdisplay(), sibling, &dw, &parent, &wins, &nwins))
         {
-            XFree(wins);
+            if (nwins)
+            {
+                XFree(wins);
+            }
         }
-    }
 
-    if (parent != None)
-    {
-      debug("Parent = %ld", parent);
-    }
+        if (parent != None && parent != dw )
+            sibling = parent;
+    } while ( parent != None && parent != dw );
 
     // Set animation's stacking order to be above the window manager's
     // decoration of target window.
     XWindowChanges values;
-    values.sibling = parent != None ? parent : mTargetWin;
+    values.sibling = sibling;
     values.stack_mode = Above;
     XConfigureWindow(qt_xdisplay(), mAmor->winId(), CWSibling | CWStackMode,
                      &values);
@@ -355,7 +371,7 @@ QRect Amor::windowGeometry(WId win)
         rect.setRect(x, y, attr.width, attr.height);
     }
 
-    debug("Window geometry: %d, %d, %d x %d", rect.x(), rect.y(), rect.width(), rect.height());
+    kdDebug(10000) << "Window geometry: " << rect.x() << ", " << rect.y() << ", " << rect.width() << " x " << rect.height() << endl;
 
     return rect;
 }
@@ -516,11 +532,7 @@ void Amor::slotAbout()
                 i18n("Amusing Misuse Of Resources\n\n") +
                 i18n("Copyright (c) 1999 Martin R. Jones <mjones@kde.org>\n") +
                 "\nhttp://www.powerup.com.au/~mjones/amor/";
-    QMessageBox mb;
-    mb.setText(about);
-    mb.setCaption(i18n("About Amor"));
-    mb.setIcon(QMessageBox::Information);
-    mb.show();
+    KMessageBox::about(0, about, i18n("About Amor"));
 }
 
 //---------------------------------------------------------------------------
@@ -529,7 +541,7 @@ void Amor::slotAbout()
 //
 void Amor::slotWindowActivate(WId win)
 {
-    debug("Window activated");
+    kdDebug(10000) << "Window activated" << endl;
 
     mTimer->stop();
     mNextTarget = win;
@@ -565,7 +577,7 @@ void Amor::slotWindowActivate(WId win)
 //
 void Amor::slotWindowRemove(WId win)
 {
-    debug("Window removed");
+    kdDebug(10000) << "Window removed" << endl;
     if (win == mTargetWin)
     {
         // This is an active event that affects the target window
@@ -583,7 +595,7 @@ void Amor::slotWindowRemove(WId win)
 //
 void Amor::slotStackingChanged()
 {
-    debug("Stacking changed");
+    kdDebug(10000) << "Stacking changed" << endl;
 
     // This is an active event that affects the target window
     time(&mActiveTime);
@@ -599,7 +611,7 @@ void Amor::slotStackingChanged()
 //
 void Amor::slotWindowChange(WId win)
 {
-    debug("Window changed");
+    kdDebug(10000) << "Window changed" << endl;
 
     if (win != mTargetWin)
     {
@@ -609,10 +621,12 @@ void Amor::slotWindowChange(WId win)
     // This is an active event that affects the target window
     time(&mActiveTime);
 
-    if (KWin::windowState(mTargetWin) == KWin::IconicState ||
-        KWin::windowState(mTargetWin) == KWin::WithdrawnState)
+    KWin::Info info = KWin::info( mTargetWin );
+
+    if (info.isIconified() ||
+        info.mappingState == NET::Withdrawn)
     {
-        debug("Iconic");
+        kdDebug(10000) << "Iconic" << endl;
         // The target window has been iconified
         selectAnimation(Destroy);
         mTargetWin = None;
@@ -622,7 +636,8 @@ void Amor::slotWindowChange(WId win)
     else
     {
         // The size or position of the window has changed.
-        mTargetRect = windowGeometry(mTargetWin);
+//        mTargetRect = windowGeometry(mTargetWin);
+        mTargetRect = info.frameGeometry;
 
         // make sure the animation is still on the window.
         if (mCurrAnim->frame())
