@@ -8,10 +8,8 @@
 #include <stdlib.h>
 #include <kconfig.h>
 #include <kapp.h>
-#if QT_VERSION >= 199
 #include <kglobal.h>
 #include <kstddirs.h>
-#endif
 #include "amoranim.h"
 #include "amorpm.h"
 
@@ -44,9 +42,7 @@ const QPixmap *AmorAnim::frame()
     const QPixmap *pixmap = 0;
 
     if (validFrame())
-    {
-        pixmap = AmorPixmapManager::manager()->pixmap(mSequence.at(mCurrent));
-    }
+        pixmap = AmorPixmapManager::manager()->pixmap(*mSequence.at(mCurrent));
 
     return pixmap;
 }
@@ -60,15 +56,16 @@ void AmorAnim::readConfig(KConfigBase &config)
 {
     // Read the list of frames to display and load them into the pixmap
     // manager.
-    int frames = config.readListEntry("Sequence",mSequence);
-    for (int i = 0; i < frames; i++)
+    mSequence = config.readListEntry("Sequence");
+    int frames = mSequence.count();
+    for ( QStringList::Iterator it = mSequence.begin();
+          it != mSequence.end();
+          ++it )
     {
         const QPixmap *pixmap =
-                        AmorPixmapManager::manager()->load(mSequence.at(i));
+                        AmorPixmapManager::manager()->load(*it);
         if (pixmap)
-        {
             mMaximumSize = mMaximumSize.expandedTo(pixmap->size());
-        }
     }
 
     // Read the delays between frames.
@@ -76,9 +73,7 @@ void AmorAnim::readConfig(KConfigBase &config)
     int entries = config.readListEntry("Delay",list);
     mDelay.resize(frames);
     for (int i = 0; i < entries && i < frames; i++)
-    {
         mDelay[i] = atoi(list.at(i));
-    }
 
     // Read the distance to move between frames and calculate the total
     // distance that this aniamtion moves from its starting position.
@@ -94,22 +89,18 @@ void AmorAnim::readConfig(KConfigBase &config)
     entries = config.readListEntry("HotspotX",list);
     mHotspot.resize(frames);
     for (int i = 0; i < entries && i < frames; i++)
-    {
         mHotspot[i].setX(atoi(list.at(i)));
-    }
 
     entries = config.readListEntry("HotspotY",list);
     for (int i = 0; i < entries && i < frames; i++)
-    {
         mHotspot[i].setY(atoi(list.at(i)));
-    }
 
     // Add the overlap of the last frame to the total movement.
     const QPoint &lastHotspot = mHotspot[mHotspot.size()-1];
     if (mTotalMovement >= 0)
     {
         const QPixmap *lastFrame =
-                    AmorPixmapManager::manager()->pixmap(mSequence.getLast());
+                    AmorPixmapManager::manager()->pixmap(mSequence.last());
         if (lastFrame)
         {
             mTotalMovement += (lastFrame->width() - lastHotspot.x());
@@ -135,33 +126,17 @@ AmorThemeManager::AmorThemeManager()
 AmorThemeManager::~AmorThemeManager()
 {
     if (mConfig)
-    {
         delete mConfig;
-    }
 }
 
 //---------------------------------------------------------------------------
 //
-bool AmorThemeManager::setTheme(const char *file)
+bool AmorThemeManager::setTheme(const QString & file)
 {
-#if QT_VERSION >= 199
     mPath = locate("appdata", file);
-#else
-    mPath = KApplication::localkdedir().copy();
-    mPath += "/share/apps/amor/";
-    mPath += file;
 
-    if (access(mPath, R_OK))
-    {
-        mPath = KApplication::kde_datadir().copy();
-        mPath += "/amor/";
-        mPath += file;
-    }
-#endif
     if (mConfig)
-    {
         delete mConfig;
-    }
 
     mConfig = new KSimpleConfig(mPath, true);
     mConfig->setGroup("Config");
@@ -170,9 +145,7 @@ bool AmorThemeManager::setTheme(const char *file)
     // pixmap manager.
     QString pixmapPath = mConfig->readEntry("PixmapPath");
     if (pixmapPath.isEmpty())
-    {
         return false;
-    }
 
     if (pixmapPath[0] == '/')
     {
@@ -198,14 +171,12 @@ bool AmorThemeManager::setTheme(const char *file)
 //
 // Select an animimation randomly from a group
 //
-AmorAnim *AmorThemeManager::random(const char *group)
+AmorAnim *AmorThemeManager::random(const QString & group)
 {
     AmorAnimationGroup *animGroup = mAnimations.find(group);
 
     if (animGroup)
-    {
         return animGroup->at(kapp->random()%animGroup->count());
-    }
 
     return 0;
 }
@@ -214,7 +185,7 @@ AmorAnim *AmorThemeManager::random(const char *group)
 //
 // Read an animation group.
 //
-bool AmorThemeManager::readGroup(const char *seq)
+bool AmorThemeManager::readGroup(const QString & seq)
 {
     AmorPixmapManager::manager()->setPixmapDir(mPath);
 
@@ -250,9 +221,7 @@ bool AmorThemeManager::readGroup(const char *seq)
 
     // Couldn't read any entries at all
     if (entries == 0)
-    {
         return false;
-    }
 
     mAnimations.insert(seq, animList);
 
