@@ -37,8 +37,8 @@ class EyesApplet : public KPanelApplet
   Q_OBJECT
 	
 public:
-  EyesApplet( QWidget* parent = 0, const char* name = 0 );
-  ~EyesApplet();
+  EyesApplet(const QString& configFile, Type t = Normal, int actions = 0,
+             QWidget *parent = 0, const char *name = 0);
 
   int widthForHeight(int height);
   int heightForWidth(int width);
